@@ -16,10 +16,6 @@ class geom_point(geom):
             layer["s"] = layer["size"]
             del layer["size"]
 
-        if "cmap" in layer:
-            layer["c"] = layer["color"]
-            del layer["color"]
-        
         # for some reason, scatter doesn't default to the same color styles
         # as the axes.color_cycle
         if "color" not in layer and "cmap" not in layer:
