@@ -131,7 +131,8 @@ class ggplot(object):
         figure = self.draw()
         # We're going to default to making the plot appear when __repr__ is
         # called.
-        figure.show()
+        #figure.show() # doesn't work in ipython notebook
+        plt.show()
         # TODO: We can probably get more sugary with this
         return "<ggplot: (%d)>" % self.__hash__()
 
@@ -287,7 +288,12 @@ class ggplot(object):
                         plt.table(cellText=[[title]], loc='top',
                                 cellLoc='center', cellColours=[['lightgrey']])
                         cntr += 1
-                    scale_facet_wrap(self.n_wide, self.n_high, [], self.facet_scales)
+
+                    # NOTE: Passing n_high for cols (instead of n_wide) and
+                    # n_wide for rows because in all previous calls to
+                    # plt.subplot, n_wide is passed as the number of rows, not
+                    # columns.
+                    scale_facet_wrap(self.n_wide, self.n_high, range(cntr), self.facet_scales)
             else:
                 for layer in self._get_layers(self.data):
                     for geom in self.geoms:
